@@ -8,9 +8,49 @@ from alas_ce0.management.task import TaskClient
 def get_delivery_order_process_type_dic():
     return {
         2: "Recepción Física TL (Viejo Formato)",
-        10: "Recepción Física TL (Nuevo Formato)",
         8: "Agendamiento de Entrega",
         9: "Ingreso a Ce0",
+        10: "Recepción Física TL (Nuevo Formato)",
+    }
+    
+def get_delivery_order_status_dic():
+    return {
+        1: "Planificación",
+        2: "Planificación Modificada",
+        3: "Planificación Aprobada",
+        4: "Recibida Virtual",
+        5: "Recibida Físico",
+        6: "En Maquilado",
+        7: "Rechazado B2B",
+        8: "Espera TI",
+        9: "Viajando a SER",
+        10: "Recibido SER",
+        11: "Espera Reemplazo",
+        12: "Entrega Confirmada",
+        13: "Entrega No Confirmada",
+        14: "Entrega Aplazada",
+        15: "Entrega Rechazada",
+        16: "Entrega Ruteada",
+        17: "Viajando B2C",
+        18: "Entregada",
+        19: "No Entregada",
+        20: "PackagingIssueReturned",
+        21: "ODFReturned",
+        22: "ODSFReturned",
+        23: "Pending",
+        24: "PrioritizedPending",
+        25: "No Entregable",
+        26: "B2BReturning",
+        27: "B2BReturned",
+        28: "Evaluada B2C",
+        29: "Rechazada en Terreno",
+        30: "Reagendada",
+        31: "Intento de Contacto",
+        32: "Recibido CD",
+        33: "Recibido Mensajero",
+        34: "Recuperada",
+        35: "Rechazado Cliente",
+        36: "Rechazado Alas"
     }
 
 
@@ -81,6 +121,33 @@ class DeliveryOrderStatusType(Enum):
     DistributionCenterReceived = 32
     DeliveryCourierReceived = 33
     Recovered = 34
+    B2CReceptionRejected = 35
+    ALASRejected = 36
+    
+    
+def get_macro_status(delivery_order):
+    in_route_amount = len(filter(lambda x: x == 17, delivery_order['statuses']))
+    status = get_delivery_order_status_dic()
+
+    if delivery_order['status'] in [
+        DeliveryOrderStatusType.VirtuallyReceived.value,
+        DeliveryOrderStatusType.PhysicallyReceived.value,
+        DeliveryOrderStatusType.B2BReceptionRejected.value,
+        DeliveryOrderStatusType.Delivered.value] or delivery_order['status'] >= DeliveryOrderStatusType.ALASRejected.value:
+        return status[delivery_order['status']]
+    elif delivery_order['status'] in [
+        DeliveryOrderStatusType.DeliveryRejected.value,
+        DeliveryOrderStatusType.B2CRejected.value,
+        DeliveryOrderStatusType.B2CReceptionRejected.value]:
+        return 'Rechazado Cliente'
+    elif delivery_order['status'] == DeliveryOrderStatusType.B2CTraveling.value:
+        return 'En Ruta {0}'.format(in_route_amount)
+    elif delivery_order['status'] == DeliveryOrderStatusType.NotDeliverable.value:
+        return 'Rechazado 3 Intentos'
+    else:
+        if in_route_amount > 0:
+            return 'Pendiente Ruta {0}'.format(in_route_amount + 1)
+    return 'En Planta'
 
 
 class DeliveryOrderRequestClient(EntityClientBase):
@@ -109,6 +176,9 @@ class DeliveryOrderClient(EntityClientBase):
         else:
             return self.http_post_json(self.entity_endpoint_base_url + "_create-from-request", params)
 
+    def create_delivery_order_label_sync(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_create-delivery-order-label-sync", params)
+
     def get_agenda(self, date_from, date_to, process_types, stakeholder_types=None):
         param = {
             'date_from': date_from,
@@ -125,18 +195,23 @@ class DeliveryOrderClient(EntityClientBase):
     def change_planning(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_change-planning".format(id), params)
 
-    def upload_file(self, user_name, sender_code, base64_content, file_format="txt"):
+    def upload_file(self, user_name, sender_code, base64_content, file_format="txt", file_name=None, family=1):
         params = {
             'user_name': user_name,
             'sender_code': sender_code,
             'base64_content': base64_content,
             'format': file_format,
+            'file_name': file_name,
+            'family': family
         }
         return self.http_post_json(self.entity_endpoint_base_url + "_upload-file", params)
 
     def validate_customer(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_validate-customer".format(id), params)
 
+    def confirm_b2c_delivery(self, id, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_confirm-b2c-delivery".format(id), params)
+
     def search_for_daily_planning(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_search-for-daily-planning", params)
 
@@ -146,15 +221,24 @@ class DeliveryOrderClient(EntityClientBase):
     def search_for_route_creation(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_search-for-route-creation", params)
 
+    def get_items(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_get-items", params)
+
     def send_notification(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_send-notification".format(id), params)
 
     def change_b2c_delivery(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_change-b2c-delivery".format(id), params)
 
+    def masive_change_b2c_delivery(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_masive_change-b2c-delivery", params)
+
     def change_destination(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_change-destination".format(id), params)
 
+    def set_b2c_informed_geo_location(self, id, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_set-b2c-informed-geo-location".format(id), params)
+
     def route_now(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_route-now".format(id), params)
 
@@ -184,8 +268,17 @@ class DeliveryOrderClient(EntityClientBase):
     def validate_package(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_validate-package".format(id), params)
 
+    def process_create_labels_by_ids(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_process-create-labels-by-ids", params)
+
+    def create_label_sync(self, id, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_create-label-sync".format(id), params)
+
     def process_physical_reception(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_process-physical-reception", params)
+    
+    def slack_report_send(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_slack-report-send", params)
 
     def physically_receive(self, id, event_info, pasync=True):
         if pasync:
