@@ -12,6 +12,9 @@ class BulkClient(EntityClientBase):
     def generate_bulks(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_generate-bulks", params)
 
+    def change_status(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_change-status", params)
+
     def ti_controlled_receive(self, code):
         return self.http_post_json(self.entity_endpoint_base_url + "_ti-controlled-receive", code)
 
